Computes the pdf, cdf, quantile, and random numbers and estimates the parameters of the exponentiated gull alpha power family of distribution specified by the cdf.
$$F(x,{\Theta}) = \left[\frac{\alpha G(x)}{\alpha^{G(x)}}\right]^{b}$$ where \(\theta\) is the baseline family parameter vector. Also, b>0 are the extra parameters induced to the baseline cumulative distribution function (cdf) G whose pdf is g.
Here, the baseline G refers to the cdf of: exponential, rayleigh and weibull.
regap(n, dist, param)
qegap(p, dist, param, log.p = FALSE, lower.tail = TRUE)
pegap(data, dist, param, log.p = FALSE, lower.tail = TRUE)
degap(data, dist, param, log = FALSE)
mlegap(data, dist,starts, method="SANN")number of realizations to be generated.
quantile value between 0 and 1.
Vector of observations.
parameter vector \(\Theta=(b,\theta,\alpha)\)
If TRUE, then log(pdf) is returned.
If TRUE, then log(cdf) is returned and quantile is computed for exp(-p).
If FALSE, then 1-cdf is returned and quantile is computed for 1-p.
The name of family's pdf including: "exponential", "rayleigh", "weibull", "lomax"
the method for optimizing the log likelihood function. It can be one of "Nelder-Mead", "BFGS", "CG", "L-BFGS-B" or "SANN". The default is "BFGS". The details of these methods can be found in the manual pages for optim
initial values of (theta, b, alpha)
A vector of the same length as data, giving the pdf values computed at data.
A vector of the same length as data, giving the cdf values computed at data.
A vector of the same length as p, giving the quantile values computed at p.
A vector of the same length as n, giving the random numbers realizations.
A sequence of goodness-of-fit statistics such as: Akaike Information Criterion (AIC), Consistent Akaike Information Criterion (CAIC), Bayesian Information Criterion (BIC), Hannan-Quinn information criterion (HQIC), Cramer-von Misses statistic (CM), Anderson Darling statistic (AD), log-likelihood statistic (log). The Kolmogorov-Smirnov (KS) test statistic and corresponding p-value and the convergence status.
# NOT RUN {
x=runif(10,min=0,max=1)
regap(10,"exp",c(0.3,0.5,0.7))
qegap(0.6,"exp",c(0.3,0.5,0.7))
pegap(x,"exp",c(0.3,0.5,0.7))
degap(x,"exp",c(0.3,0.5,0.7))
mlegap(x,"exp",c(0.3,0.5,0.7))
# }
Run the code above in your browser using DataLab